==> libreoffice-still-sdk-7.3.7-2-aarch64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/files_a.js <==
var searchData=
[
  ['kcharactertype_2eidl_0',['KCharacterType.idl',['../KCharacterType_8idl.html',1,'']]],
  ['keeptogether_2eidl_1',['KeepTogether.idl',['../KeepTogether_8idl.html',1,'']]],
  ['key_2eidl_2',['Key.idl',['../sdbcx_2Key_8idl.html',1,'(Global Namespace)'],['../awt_2Key_8idl.html',1,'(Global Namespace)']]],
  ['keycolumn_2eidl_3',['KeyColumn.idl',['../KeyColumn_8idl.html',1,'']]],
  ['keycolumndescriptor_2eidl_4',['KeyColumnDescriptor.idl',['../KeyColumnDescriptor_8idl.html',1,'']]],
  ['keydescriptor_2eidl_5',['KeyDescriptor.idl',['../KeyDescriptor_8idl.html',1,'']]],
  ['keyevent_2eidl_6',['KeyEvent.idl',['../KeyEvent_8idl.html',1,'']]],
  ['keyexception_2eidl_7',['KeyException.idl',['../KeyException_8idl.html',1,'']]],
  ['keyfunction_2eidl_8',['KeyFunction.idl',['../KeyFunction_8idl.html',1,'']]],
  ['keygroup_2eidl_9',['KeyGroup.idl',['../KeyGroup_8idl.html',1,'']]],
  ['keymodifier_2eidl_10',['KeyModifier.idl',['../KeyModifier_8idl.html',1,'']]],
  ['keyrule_2eidl_11',['KeyRule.idl',['../KeyRule_8idl.html',1,'']]],
  ['keystroke_2eidl_12',['KeyStroke.idl',['../KeyStroke_8idl.html',1,'']]],
  ['keytype_2eidl_13',['KeyType.idl',['../KeyType_8idl.html',1,'']]],
  ['keyusage_2eidl_14',['KeyUsage.idl',['../KeyUsage_8idl.html',1,'']]],
  ['keywords_2eidl_15',['Keywords.idl',['../Keywords_8idl.html',1,'']]],
  ['knumberformattype_2eidl_16',['KNumberFormatType.idl',['../KNumberFormatType_8idl.html',1,'']]],
  ['knumberformatusage_2eidl_17',['KNumberFormatUsage.idl',['../KNumberFormatUsage_8idl.html',1,'']]],
  ['kparsetokens_2eidl_18',['KParseTokens.idl',['../KParseTokens_8idl.html',1,'']]],
  ['kparsetype_2eidl_19',['KParseType.idl',['../KParseType_8idl.html',1,'']]]
];

==> libreoffice-still-sdk-7.6.5-1-aarch64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/files_a.js <==
var searchData=
[
  ['kcharactertype_2eidl_0',['KCharacterType.idl',['../KCharacterType_8idl.html',1,'']]],
  ['keeptogether_2eidl_1',['KeepTogether.idl',['../KeepTogether_8idl.html',1,'']]],
  ['key_2eidl_2',['Key.idl',['../awt_2Key_8idl.html',1,'(Global Namespace)'],['../sdbcx_2Key_8idl.html',1,'(Global Namespace)']]],
  ['keycolumn_2eidl_3',['KeyColumn.idl',['../KeyColumn_8idl.html',1,'']]],
  ['keycolumndescriptor_2eidl_4',['KeyColumnDescriptor.idl',['../KeyColumnDescriptor_8idl.html',1,'']]],
  ['keydescriptor_2eidl_5',['KeyDescriptor.idl',['../KeyDescriptor_8idl.html',1,'']]],
  ['keyevent_2eidl_6',['KeyEvent.idl',['../KeyEvent_8idl.html',1,'']]],
  ['keyexception_2eidl_7',['KeyException.idl',['../KeyException_8idl.html',1,'']]],
  ['keyfunction_2eidl_8',['KeyFunction.idl',['../KeyFunction_8idl.html',1,'']]],
  ['keygroup_2eidl_9',['KeyGroup.idl',['../KeyGroup_8idl.html',1,'']]],
  ['keymodifier_2eidl_10',['KeyModifier.idl',['../KeyModifier_8idl.html',1,'']]],
  ['keyrule_2eidl_11',['KeyRule.idl',['../KeyRule_8idl.html',1,'']]],
  ['keystroke_2eidl_12',['KeyStroke.idl',['../KeyStroke_8idl.html',1,'']]],
  ['keytype_2eidl_13',['KeyType.idl',['../KeyType_8idl.html',1,'']]],
  ['keyusage_2eidl_14',['KeyUsage.idl',['../KeyUsage_8idl.html',1,'']]],
  ['keywords_2eidl_15',['Keywords.idl',['../Keywords_8idl.html',1,'']]],
  ['knumberformattype_2eidl_16',['KNumberFormatType.idl',['../KNumberFormatType_8idl.html',1,'']]],
  ['knumberformatusage_2eidl_17',['KNumberFormatUsage.idl',['../KNumberFormatUsage_8idl.html',1,'']]],
  ['kparsetokens_2eidl_18',['KParseTokens.idl',['../KParseTokens_8idl.html',1,'']]],
  ['kparsetype_2eidl_19',['KParseType.idl',['../KParseType_8idl.html',1,'']]]
];
